==================
Postalcodes Mexico
==================


.. image:: https://img.shields.io/pypi/v/postalcodes_mexico.svg
        :target: https://pypi.python.org/pypi/postalcodes_mexico

.. image:: https://img.shields.io/travis/FlowFX/postalcodes_mexico.svg
        :target: https://travis-ci.org/flowfx/postalcodes_mexico

.. image:: https://readthedocs.org/projects/postalcodes-mexico/badge/?version=latest
        :target: https://postalcodes-mexico.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/FlowFX/postalcodes_mexico/shield.svg
     :target: https://pyup.io/repos/github/FlowFX/postalcodes_mexico/
     :alt: Updates




Determines large parts of a Mexican postal address from its postal code (C.P.).


* Free software: MIT license
* Documentation: https://postalcodes-mexico.readthedocs.io.


Features
--------

Postalcods mexico provides a function `places` that returns a list of named tuples with all places in Mexico that share the given postal code.

Reference
---------
The data used in this package comes from the official website of the `Mexican Postal Service`_ (Correos Mexico). On the download page of the `catalogue of postal codes`_ it is stated that this data is not to be commercialized:

    El Catálogo Nacional de Códigos Postales, es elaborado por el Servicio Postal Mexicano y se proporciona en forma gratuita, no estando permitida su comercialización, total o parcial.

http://www.correosdemexico.gob.mx/lservicios/servicios/CodigoPostal_Exportar.aspx

.. _Mexican Postal Service: http://www.correosdemexico.com.mx/Paginas/Inicio.aspx
.. _catalogue of postal codes: http://www.correosdemexico.gob.mx/lservicios/servicios/CodigoPostal_Exportar.aspx

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
